==> namebase-0.0.8.tar.gz: lib/namebase.dart <==
library namebase;

import 'package:get/get.dart';
import 'package:namebase/src/client.dart';
import 'package:namebase/src/models/record.dart';
import 'package:namebase/src/models/response.dart';
import 'src/models/status.dart';

export 'src/models/record.dart';
export 'src/models/response.dart';
export 'src/models/result.dart';
export 'src/models/status.dart';
export 'src/client.dart';

/// ### Namebase
/// - Class Manages Namebase DNS Entries
/// - Provides methods to create, update, and delete Namebase DNS Entries.
class Namebase {
  /// User Record Name Reference
  static late String? userName;

  /// Checks if the user record name has been set.
  static bool get hasUser => userName != null;

  // Internal Reference
  static late final APIClient _internal;

  /// ### Namebase `init()`
  /// - Initializes the Namebase API.
  /// - Sets the user record name.
  /// - Sets the internal reference to the Namebase API.
  /// **Required** : `API_KEY`, `API_SECRET`
  static void init({required String key, required String secret}) {
    _internal = APIClient(key: key, secret: secret);
  }

  /// ### Namebase `initName()`
  /// - Sets clients **User Name**
  /// - Enables user Auth checking
  /// **Required** : (`String`) name
  static void initName(String name) {
    // Check for SName
    if (Namebase.userName == null) {
      Namebase.userName = name;
    }
  }

  /// #### `addRecords()`
  /// - Method Creates New Item(s) on DNS Table
  /// - Returns `true` if successful, `false` otherwise
  /// **Required** : `List<DNSRecord>`
  static Future<bool> addRecords(List<DNSRecord> records) => _internal.addRecords(records);

  /// #### `findRecord()`
  /// - Returns `DNSRecord` if found, `null` otherwise
  /// **Required** : `(String)-query`
  static Future<DNSRecord?> findRecord(String query) async {
    // Refresh known records
    final result = await refresh();

    // Find Record
    final data = result.records.firstWhere(
      (e) => e.host.toLowerCase() == query.toLowerCase(),
      orElse: () => DNSRecord.blank(),
    );

    // Check if record is blank
    if (data.isBlank) {
      return null;
    }
    return data;
  }

  /// #### `hasAllRecords()`
  /// - Method to check if all `User` records are in the Namebase DNS Table.
  /// - Sets **User Name** if Provided
  /// **Optional** : `SName`
  static Future<bool> hasAllRecords() async {
    // Return SName
    return await hasAuthRecord() && await hasSNameRecord();
  }

  /// #### `hasAuthRecord()`
  /// - Method to check Auth Record exists for user
  /// - Sets **User Name** if Provided
  /// **Optional** : `SName`
  static Future<bool> hasAuthRecord() async {
    // User Records
    final list = await userRecords();
    return list.any((e) => e.isAuth);
  }

  /// #### `hasSNameRecord()`
  /// - Method to check SName Record exists for user
  /// - Sets **User Name** if Provided
  /// **Optional** : `SName`
  static Future<bool> hasSNameRecord() async {
    // User Records
    final list = await userRecords();
    return list.any((e) => e.isName);
  }

  /// #### `replaceRecord()`
  /// - Replaces a single record in the DNS Table
  /// - Returns `true` if successful
  /// - Returns `false` if the record does not exist
  /// **Required** : `DNSRecord`
  static Future<bool> replaceRecord(DNSRecord record) => _internal.replaceRecord(record);

  /// #### `refresh()`
  /// - Returns `NamebaseResponse` with *records* (`List<DNSRecord>`)
  ///   and *success* (`bool`)
  static Future<NamebaseResponse> refresh() => _internal.refresh();

  /// #### `userRecords()`
  /// - Returns `List<DNSRecord>` of User Records
  /// - Sets **User Name** if Provided
  /// **Optional** : `SName`
  static Future<List<DNSRecord>> userRecords({String? sName}) async {
    // Check for SName
    if (userName != null && Namebase.userName == null) {
      Namebase.userName = userName;
    }

    // Refresh Records
    final result = await refresh();

    // Check Username set
    if (hasUser) {
      final records = result.records.where(
        (e) => e.host.toLowerCase() == userName || e.name.toLowerCase() == userName,
      );
      return records.toList();
    } else {
      final records = result.records.where(
        (e) => e.host.toLowerCase() == userName || e.name.toLowerCase() == userName,
      );
      return records.toList();
    }
  }

  /// #### `validateName()`
  /// - Validates SName as Valid characters
  /// - Returns `NameStatus`
  /// **Required** : `SName`
  static Future<NameStatus> validateName(String sName) async {
    final result = await refresh();
    // Check Alphabet Only
    if (!sName.isAlphabetOnly) {
      return NameStatus.InvalidCharacters;
    } else {
      // Update Status
      if (sName.length > 3) {
        // Check Available
        if (result.checkName(NameCheckType.Unavailable, sName)) {
          return NameStatus.Unavailable;
        }
        // Check Unblocked
        else if (result.checkName(NameCheckType.Blocked, sName)) {
          return NameStatus.Blocked;
        }
        // Check Unrestricted
        else if (result.checkName(NameCheckType.Restricted, sName)) {
          return NameStatus.Restricted;
        }
        // Check Valid
        else {
          return NameStatus.Available;
        }
      } else {
        return NameStatus.TooShort;
      }
    }
  }
}

==> namebase-0.1.0.tar.gz: lib/namebase.dart <==
library namebase;

import 'package:get/get.dart';
import 'package:namebase/src/client.dart';
import 'package:namebase/src/models/record.dart';
import 'package:namebase/src/models/response.dart';
import 'src/models/status.dart';

export 'src/models/record.dart';
export 'src/models/response.dart';
export 'src/models/result.dart';
export 'src/models/status.dart';
export 'src/client.dart';

/// ### Namebase
/// - Class Manages Namebase DNS Entries
/// - Provides methods to create, update, and delete Namebase DNS Entries.
class Namebase {
  /// User Record Name Reference
  static late String? userName;

  /// Checks if the user record name has been set.
  static bool get hasUser => userName != null;

  // Internal Reference
  static late final APIClient _internal;

  /// ### Namebase `init()`
  /// - Initializes the Namebase API.
  /// - Sets the user record name.
  /// - Sets the internal reference to the Namebase API.
  /// **Required** : `API_KEY`, `API_SECRET`
  static void init({required String key, required String secret}) {
    _internal = APIClient(key: key, secret: secret);
  }

  /// ### Namebase `initName()`
  /// - Sets clients **User Name**
  /// - Enables user Auth checking
  /// **Required** : (`String`) name
  static void initName(String name) {
    // Check for SName
    if (Namebase.userName == null) {
      Namebase.userName = name;
    }
  }

  /// #### `addRecords()`
  /// - Method Creates New Item(s) on DNS Table
  /// - Returns `true` if successful, `false` otherwise
  /// **Required** : `List<DNSRecord>`
  static Future<bool> addRecords(List<DNSRecord> records) => _internal.addRecords(records);

  /// #### `findRecord()`
  /// - Returns `DNSRecord` if found, `null` otherwise
  /// **Required** : `(String)-query`
  static Future<DNSRecord?> findRecord(String query) async {
    // Refresh known records
    final result = await refresh();

    // Find Record
    final data = result.records.firstWhere(
      (e) => e.host.toLowerCase() == query.toLowerCase(),
      orElse: () => DNSRecord.blank(),
    );

    // Check if record is blank
    if (data.isBlank) {
      return null;
    }
    return data;
  }

  /// #### `hasAllRecords()`
  /// - Method to check if all `User` records are in the Namebase DNS Table.
  /// - Sets **User Name** if Provided
  /// **Optional** : `SName`
  static Future<bool> hasAllRecords() async {
    // Return SName
    return await hasAuthRecord() && await hasSNameRecord();
  }

  /// #### `hasAuthRecord()`
  /// - Method to check Auth Record exists for user
  /// - Sets **User Name** if Provided
  /// **Optional** : `SName`
  static Future<bool> hasAuthRecord() async {
    // User Records
    final list = await userRecords();
    return list.any((e) => e.isAuth);
  }

  /// #### `hasSNameRecord()`
  /// - Method to check SName Record exists for user
  /// - Sets **User Name** if Provided
  /// **Optional** : `SName`
  static Future<bool> hasSNameRecord() async {
    // User Records
    final list = await userRecords();
    return list.any((e) => e.isName);
  }

  /// #### `replaceRecord()`
  /// - Replaces a single record in the DNS Table
  /// - Returns `true` if successful
  /// - Returns `false` if the record does not exist
  /// **Required** : `DNSRecord`
  static Future<bool> replaceRecord(DNSRecord record) => _internal.replaceRecord(record);

  /// #### `refresh()`
  /// - Returns `NamebaseResponse` with *records* (`List<DNSRecord>`)
  ///   and *success* (`bool`)
  static Future<NamebaseResponse> refresh() => _internal.refresh();

  /// #### `userRecords()`
  /// - Returns `List<DNSRecord>` of User Records
  /// - Sets **User Name** if Provided
  /// **Optional** : `SName`
  static Future<List<DNSRecord>> userRecords() async {
    // Refresh Records
    final result = await refresh();

    // Check Username set
    if (hasUser) {
      final records = result.records.where(
        (e) => e.host.toLowerCase() == userName || e.name.toLowerCase() == userName,
      );
      return records.toList();
    } else {
      final records = result.records.where(
        (e) => e.host.toLowerCase() == userName || e.name.toLowerCase() == userName,
      );
      return records.toList();
    }
  }

  /// #### `validateName()`
  /// - Validates SName as Valid characters
  /// - Returns `NameStatus`
  /// **Required** : `SName`
  static Future<NameStatus> validateName(String sName) async {
    final result = await refresh();
    // Check Alphabet Only
    if (!sName.isAlphabetOnly) {
      return NameStatus.InvalidCharacters;
    } else {
      // Update Status
      if (sName.length > 3) {
        // Check Available
        if (result.checkName(NameCheckType.Unavailable, sName)) {
          return NameStatus.Unavailable;
        }
        // Check Unblocked
        else if (result.checkName(NameCheckType.Blocked, sName)) {
          return NameStatus.Blocked;
        }
        // Check Unrestricted
        else if (result.checkName(NameCheckType.Restricted, sName)) {
          return NameStatus.Restricted;
        }
        // Check Valid
        else {
          return NameStatus.Available;
        }
      } else {
        return NameStatus.TooShort;
      }
    }
  }
}
